# $Id: Handel.pm 4 2004-12-28 03:01:15Z claco $
package Handel;
use strict;
use warnings;
use vars qw($VERSION);

$VERSION = '0.01_01';

1;
__END__

=head1 NAME

Handel - Simple commerce framework with AxKit support

=head1 AUTHOR

    Christopher H. Laco
    CPAN ID: CLACO
    cpan@chrislaco.com
    http://today.icantfocus.com/blog/
