# $Id: en_us.pm 4 2004-12-28 03:01:15Z claco $
package Handel::L10N::en_us;
use strict;
use warnings;
use vars qw(%Lexicon);

BEGIN {
    use base 'Handel::L10N';
};

%Lexicon = (

);

1;
__END__

=head1 NAME

Handel::L10N::en_us - US English Language Pack

=head1 AUTHOR

    Christopher H. Laco
    CPAN ID: CLACO
    cpan@chrislaco.com
    http://today.icantfocus.com/blog/