# $Id: Cart.pm 4 2004-12-28 03:01:15Z claco $
package AxKit::XSP::Handel::Cart;
use strict;

1;
__END__

=head1 NAME

AxKit::XSP::Handel::Cart - XSP Cart Taglib

=head1 AUTHOR

    Christopher H. Laco
    CPAN ID: CLACO
    cpan@chrislaco.com
    http://today.icantfocus.com/blog/
