# $Id: Iterator.pm 4 2004-12-28 03:01:15Z claco $
package Handel::Iterator;
use strict;
use warnings;

BEGIN {
    use base 'Class::DBI::Iterator';
};

1;
__END__

=head1 NAME

Handel::Iterator - Iterator

=head1 AUTHOR

    Christopher H. Laco
    CPAN ID: CLACO
    cpan@chrislaco.com
    http://today.icantfocus.com/blog/
